@@ -261,7 +261,7 @@ void MainWindow::stationsListActionTriggered()
 
 void MainWindow::settingsActionTriggered()
 {
-    s=new SettingsWidget(this, set1Name, set2Name, set3Name, landscapeOrientation, currentFont, currentFreqFontSize, currentLabelsFontSize, monoMode, quickAccess);
+    s=new SettingsWidget(this, set1Name, set2Name, set3Name, landscapeOrientation, currentFont, currentFreqFontSize, currentLabelsFontSize, monoMode, quickAccess, showCustomBackground);
     s->setAttribute(Qt::WA_Maemo5StackedWindow);
     s->setWindowFlags(s->windowFlags() | Qt::Window);
     s->setWindowTitle("Settings");
@@ -544,7 +544,7 @@ void MainWindow::helpActionTriggered()
                  "Manage Stations: tap on it to show the stations management window, where saved stations of the current set can be moved or deleted by holding down the relative icon. Tapping on the freq name button will change the current freq to that value.\n"
                  "Manual: tap on it to insert manually the desired frequency.\n"
                  "Stations List: same behavior of the small bottom left button.\n"
-                 "Speakers: tap on it to toggle speakers output. To learn more about it check the Maemo.org topic about QRadio"
+                 "Speakers: tap on it to toggle speakers output. To learn more about it check the Maemo.org topic about QRadio. \n"
                  "AutoScan: tapping on it will start the autoscan. Starting from the current freq, all stations will be saved into the current set.\n");
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addWidget(textEdit);
